@@ -33,7 +33,7 @@ display = ST7789(
 )
 
 # Make the display context
-splash = displayio.Group(max_size=10)
+splash = displayio.Group()
 display.show(splash)
 
 color_bitmap = displayio.Bitmap(display.width, display.height, 1)
@@ -59,7 +59,6 @@ text = "Hello World!"
 text_area = label.Label(terminalio.FONT, text=text, color=TEXT_COLOR)
 text_width = text_area.bounding_box[2] * FONTSCALE
 text_group = displayio.Group(
-    max_size=10,
     scale=FONTSCALE,
     x=display.width // 2 - text_width // 2,
     y=display.height // 2,
